bayespy.inference.vmp.nodes.poisson.PoissonMoments.add_converter
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonMoments.add_converter